@@ -1,5 +1,5 @@
 
-.onLoad <- function(lib, pkg) {
+.onAttach <- function(lib, pkg) {
     packageStartupMessage(paste(" Package", sQuote("exactRankTests"), 
         "is no longer under development.\n",
         "Please consider using package", sQuote("coin"), "instead.\n"))
@@ -11,4 +11,3 @@ cpermdist2 <- function(N, totsum, sc, scores, log) {
           as.integer(scores), as.logical(FALSE),
           PACKAGE="exactRankTests")
 }
-
